==> 1.0.8.tar.gz: android/src/main/kotlin/net/xinhuamm/xycloud/xinhuamm_xycloud/XYCloudManager.kt <==
package net.xinhuamm.xycloud.xinhuamm_xycloud

import android.content.Context
import android.os.Handler
import android.os.Looper
import io.flutter.plugin.common.MethodChannel

/**
 * @author ming
 * @since 2023/10/9
 * for:
 */
object XYCloudManager {

    var channel: MethodChannel? = null

    var cloudDebug: Boolean = false
    var themeColor: String = "#FF5722"
    var userAgent: String = "xinhuamm DV/1"

    fun openCloudActivity(context: Context, url: String) {
        XYCloudActivity.start(context, url)
    }

    fun setCloudIsDebug(flag: Boolean) {
        cloudDebug = flag
    }

    fun setCloudThemeColor(themeColor: String) {
        XYCloudManager.themeColor = themeColor
    }

    fun setCloudUserAgent(userAgent: String) {
        XYCloudManager.userAgent = userAgent
    }

    fun isLogin(callback: (boolean: Boolean) -> Unit) {
        getUserId {
            callback.invoke(it.isNotEmpty())
        }
    }

    fun getUserId(callback: (userId: String) -> Unit) {
        getAutoLoginParam {
            callback.invoke(it?.get("userId") ?: "")
        }
    }

    fun getAutoLoginParam(callback: (loginParams: Map<String, String>?) -> Unit) {
        invokeFlutterMethod("getLoginParam", null, object : MethodChannel.Result {
            override fun success(result: Any?) {
                if (result is Map<*, *>) {
                    callback.invoke(result as Map<String, String>)
                } else {
                    callback.invoke(null)
                }
            }

            override fun error(errorCode: String, errorMessage: String?, errorDetails: Any?) {
                callback.invoke(null)
            }

            override fun notImplemented() {

            }
        })
    }

    fun login() {
        invokeFlutterMethod("login")
    }

    fun setMethodChannel(channel: MethodChannel) {
        XYCloudManager.channel = channel
    }

    fun invokeFlutterMethod(
        method: String,
        arguments: Any? = null,
        callback: MethodChannel.Result? = null
    ) {
        Handler(Looper.getMainLooper()).post {
            channel?.invokeMethod(method, arguments, callback)
        }
    }
}

==> 1.1.1.tar.gz: android/src/main/kotlin/net/xinhuamm/xycloud/xinhuamm_xycloud/XYCloudManager.kt <==
package net.xinhuamm.xycloud.xinhuamm_xycloud

import android.content.Context
import android.os.Handler
import android.os.Looper
import io.flutter.plugin.common.MethodChannel

/**
 * @author ming
 * @since 2023/10/9
 * for:
 */
object XYCloudManager {

    var channel: MethodChannel? = null

    var cloudDebug: Boolean = false
    var themeColor: String = "#FF5722"
    var userAgent: String = "xinhuamm DV/1"

    fun openCloudActivity(context: Context, url: String) {
        XYCloudActivity.start(context, url)
    }

    fun setCloudIsDebug(flag: Boolean) {
        cloudDebug = flag
    }

    fun setCloudThemeColor(themeColor: String) {
        XYCloudManager.themeColor = themeColor
    }

    fun setCloudUserAgent(userAgent: String) {
        XYCloudManager.userAgent = userAgent
    }

    fun isLogin(callback: (boolean: Boolean) -> Unit) {
        getUserId {
            callback.invoke(it.isNotEmpty())
        }
    }

    fun getUserId(callback: (userId: String) -> Unit) {
        getUserInfo {
            callback.invoke(it?.get("userId") ?: "")
        }
    }

    fun getUserInfo(callback: (loginParams: Map<String, String>?) -> Unit) {
        invokeFlutterMethod("getUserInfo", null, object : MethodChannel.Result {
            override fun success(result: Any?) {
                if (result is Map<*, *>) {
                    callback.invoke(result as Map<String, String>)
                } else {
                    callback.invoke(null)
                }
            }

            override fun error(errorCode: String, errorMessage: String?, errorDetails: Any?) {
                callback.invoke(null)
            }

            override fun notImplemented() {

            }
        })
    }

    fun getToken(callback: (loginParams: Map<String, String>?) -> Unit) {
        invokeFlutterMethod("getToken", null, object : MethodChannel.Result {
            override fun success(result: Any?) {
                if (result is Map<*, *>) {
                    callback.invoke(result as Map<String, String>)
                } else {
                    callback.invoke(null)
                }
            }

            override fun error(errorCode: String, errorMessage: String?, errorDetails: Any?) {
                callback.invoke(null)
            }

            override fun notImplemented() {

            }
        })
    }

    fun login(callback: MethodChannel.Result? = null) {
        invokeFlutterMethod("login", null, callback)
    }

    fun setMethodChannel(channel: MethodChannel) {
        XYCloudManager.channel = channel
    }

    fun invokeFlutterMethod(
        method: String,
        arguments: Any? = null,
        callback: MethodChannel.Result? = null
    ) {
        Handler(Looper.getMainLooper()).post {
            channel?.invokeMethod(method, arguments, callback)
        }
    }
}
